@@ -4,11 +4,13 @@ import time
 from datetime import datetime
 import requests
 
-from aishield.configs import JobDetails
 from aishield.utils.exceptions import AIShieldException
 from aishield.utils import logger
 from aishield.utils.util import check_valid_filepath
-from aishield.constants import ResponseStatus
+from aishield.constants import (
+    ResponseStatus,
+    Attack
+)
 
 LOG = logger.getLogger(__name__)
 
@@ -24,7 +26,6 @@ class RequestProcessor:
         """
         self.api_endpoint = api_endpoint
         self.headers = headers
-        self.job_details = JobDetails()
 
     def register(self, payload):
         """
@@ -38,10 +39,10 @@ class RequestProcessor:
             the status of job with details having model_id, data_upload_uri, label_upload_uri, model_upload_uri
             raises AIShieldException in case of errors or if the response from server does not indicate 'SUCCESS'.
         """
-        model_registration_url = self.api_endpoint + "/AIShieldModelRegistration/v1.5"
+        model_registration_url = self.api_endpoint + "/model_registration/upload"
         status = 'failed'
         try:
-            response = requests.post(url=model_registration_url, params=payload, headers=self.headers)
+            response = requests.post(url=model_registration_url, json=payload, headers=self.headers)
             response.raise_for_status()
         except requests.RequestException as e:
             raise AIShieldException(e)
@@ -56,21 +57,20 @@ class RequestProcessor:
                     response.text[0:150], len(response.text) > 150 and '...' or ''
                 )
             )
-        if 'Data' in resp_json:
+        if 'data' in resp_json and 'urls' in resp_json['data']:
             status = 'success'
-            self.job_details.model_id = resp_json['Data']['ModelID']
-            self.job_details.data_upload_uri = resp_json['Data']['DataUploadURL']
-            self.job_details.label_upload_uri = resp_json['Data']['LabelUploadURL']
-            self.job_details.model_upload_uri = resp_json['Data']['ModelUploadURL']
+            response_json = resp_json['data']
+        else:
+            raise AIShieldException('data or urls field not found in response')
 
-        return status, self.job_details
+        return status, response_json
 
-    def upload_file(self, data_path, upload_uri):
+    def upload_file(self, file_path, upload_uri):
         """
         Upload file to a particular uri for vulnerability analysis.
         Parameters
         ----------
-        data_path: location of data file
+        file_path: location of file to be uploaded
         upload_uri : uri where file to be uploaded
 
         Returns
@@ -78,10 +78,10 @@ class RequestProcessor:
         the status of job with details
         raises AIShieldException in case of errors or if the response from server does not indicate 'SUCCESS'.
         """
-        if not check_valid_filepath(data_path):
-            raise FileNotFoundError('file at {} not found or not accessible'.format(data_path))
+        if not check_valid_filepath(file_path):
+            raise FileNotFoundError('file at {} not found or not accessible'.format(file_path))
         try:
-            data = open(data_path, 'rb')
+            data = open(file_path, 'rb')
             response = requests.request(method="PUT", url=upload_uri, data=data)
             response.raise_for_status()
         except requests.RequestException as e:
@@ -94,11 +94,12 @@ class RequestProcessor:
             status = ResponseStatus.FAILED
         return status
 
-    def send_for_analysis(self, payload):
+    def send_for_analysis(self, model_id, payload):
         """
         Sends HTTP Post request to api_endpoint for vulnerability analysis.
         Parameters
         ----------
+        model_id: str, model_id value after model registration
         payload: dictionary, which is sent as as JSON.
 
         Returns
@@ -107,51 +108,58 @@ class RequestProcessor:
         raises AIShieldException in case of errors or if the response from server does not indicate 'SUCCESS'.
         """
         status = 'failed'
-        model_analysis_url = self.api_endpoint + "/AIShieldModelAnalysis/v1.5"
+        model_analysis_url = self.api_endpoint + "/model_analyse/{}".format(model_id)
         try:
-            response = requests.post(url=model_analysis_url, params=payload, headers=self.headers)
+            response = requests.post(url=model_analysis_url, json=payload, headers=self.headers)
             response.raise_for_status()
         except requests.RequestException as e:
-            raise AIShieldException(e)
-
-        resp_json = None
+            raise AIShieldException('error response from server. Status code {} and message is {}'
+                                    .format(response.status_code, response.text))
 
+        response_json = None
         try:
-            resp_json = response.json()
+            response_json = response.json()
         except ValueError:
             raise AIShieldException(
                 'Error response from server: {}{}'.format(
                     response.text[0:150], len(response.text) > 150 and '...' or ''
                 )
             )
-        if 'job_id' in resp_json:
+        if 'job_id' in response_json:
             status = 'success'
-            self.job_details.job_id = resp_json['job_id']
-            self.job_details.job_monitor_uri = resp_json['monitor_link']
+        else:
+            raise AIShieldException('job_id field not found in response')
 
-        return status, self.job_details
+        return status, response_json
 
-    def get_job_status(self, job_id) -> str:
+
+    def get_job_status(self, job_id, analysis_type, job_payload) -> str:
         """
         Monitor progress for job id
 
         Parameters
         ----------
         job_id: id of the submitted job
+        analysis_type: analysis_type is required because pipeline varies for different analysis.
+        job_payload: payload used for the job request
 
         Returns
         -------
         Logs the status of individual steps of analysis and returns the final status of the task
         """
-        job_status_url = self.api_endpoint + "/AIShieldModelAnalysis/" + "JobStatusDetailed?JobID=" + job_id
+        job_status_url = self.api_endpoint + "/job_status_detailed?job_id={}".format(job_id)
         status_dictionary = {
             'ModelExploration_Status': 'na',
             'SanityCheck_Status': 'na',
             'QueryGenerator_Status': 'na',
             'VunerabilityEngine_Status': 'na',
+            'EvasionAnalysis_Status': 'na',
             'DefenseReport_Status': 'na',
         }
+        counts = [0] * len(status_dictionary)
         failed_api_hit_count = 0
+        final_status = 'failed'
+        failing_key = 'ModelExploration_Status'
         LOG.info('Fetching job details for job id {}'.format(job_id))
         while True:
             time.sleep(5)
@@ -160,41 +168,80 @@ class RequestProcessor:
                 job_status_payload = json.loads(job_status_response.text)
             except requests.RequestException as error:
                 failed_api_hit_count += 1
-                print("Error {}. retrying count {}  ...".format(error, failed_api_hit_count))
+                LOG.error("Error {}. retrying count {}  ...".format(error, failed_api_hit_count))
                 if failed_api_hit_count >= 3:
                     raise AIShieldException(error)
+                continue  # again try to get a successful response
 
-            final_status = 'failed'
-            failing_key = ''
-            for key in status_dictionary.keys():
+            for status_idx, key in enumerate(status_dictionary.keys()):
+                # poisoning does not have any defense component, so no need of processing further
+                if key not in job_status_payload:
+                    continue
+                # logic for IC-evasion: No QG & VE status for whitebox type
+                if analysis_type == Attack.EVASION and job_payload['use_model_api'] == 'no' \
+                        and job_payload['encryption_strategy'] == 0:
+                    if key in ['QueryGenerator_Status', 'VunerabilityEngine_Status']:
+                        continue
+
+                # General logic
                 if status_dictionary[key] == 'na':
-                    if job_status_payload[key] == 'completed' or job_status_payload[key] == 'passed':
+                    if job_status_payload[key] == 'inprogress' and status_dictionary[key] == 'na':
                         status_dictionary[key] = job_status_payload[key]
                         LOG.info(str(key) + ":" + status_dictionary[key])
                         print('running...', end='\r')
+                    elif job_status_payload[key] == 'completed' or job_status_payload[key] == 'passed':
+                        status_dictionary[key] = job_status_payload[key]
+                        counts[status_idx] += 1
+                        LOG.info(str(key) + ":" + status_dictionary[key])
+                        # Poisoning: if VE completed then pipeline is completed
+                        if analysis_type == Attack.POISONING and key == 'VunerabilityEngine_Status':
+                            final_status = 'success'
+                            break
+                        print('running...', end='\r')
                     elif job_status_payload[key] == 'failed':
                         failing_key = key
                         status_dictionary[key] = job_status_payload[key]
                         LOG.info(str(key) + ":" + status_dictionary[key])
+                        break
+                elif job_status_payload[key] == 'completed' or job_status_payload[key] == 'passed':
+                    status_dictionary[key] = job_status_payload[key]
+                    if counts[status_idx] < 1:
+                        LOG.info(str(key) + ":" + status_dictionary[key])
+                        # Poisoning: if VE completed then pipeline is completed
+                        if analysis_type == Attack.POISONING and key == 'VunerabilityEngine_Status':
+                            final_status = 'success'
+                            break
                         print('running...', end='\r')
+                    counts[status_idx] += 1
+                else:
+                    if job_status_payload[key] == 'failed':
+                        failing_key = key
+                        status_dictionary[key] = job_status_payload[key]
+                        LOG.info(str(key) + ":" + status_dictionary[key])
+                        break
 
-            if failing_key and status_dictionary[failing_key] == 'failed':
+            if job_status_payload[failing_key] == 'failed':
                 break
-
-            if status_dictionary['VunerabilityEngine_Status'] == 'passed' or status_dictionary[
-                'VunerabilityEngine_Status'] == 'completed' and job_status_payload[
-                'CurrentStatus'] == "Defense generation is not triggered":
-                LOG.info("\n Vulnerability score {} failed to cross vulnerability threshold of {}".format(
+            # success conditions
+            if analysis_type == Attack.POISONING and status_dictionary["VunerabilityEngine_Status"] == 'completed':
+                final_status = 'success'
+                break
+            if status_dictionary['VunerabilityEngine_Status'] == 'passed' \
+                    or status_dictionary['VunerabilityEngine_Status'] == 'completed' \
+                    and job_status_payload['CurrentStatus'] == "Defense generation is not triggered":
+                LOG.info("\n Defense generation not triggered. Model vulnerability score found to be {}".format(
                     job_status_payload['VulnerabiltyScore']))
                 final_status = 'success'
                 break
-            if job_status_payload['DefenseReport_Status'] == 'completed':
+            if status_dictionary["DefenseReport_Status"] == 'completed':
                 final_status = 'success'
                 break
+
         print('job run completed')
         LOG.info('Analysis completed for job id {}'.format(job_id))
         return final_status
 
+
     def get_artifacts(self, job_id, report_type, file_format, save_folder_path) -> str:
         """
         Get the artifacts like reports, attack samples or defense model
@@ -226,8 +273,9 @@ class RequestProcessor:
             file_format_id = 0
             file_format = 'zip'
 
-        job_artifact_url = self.api_endpoint + "/AIShieldModelAnalysis/" +\
-                           "GetReport?JobID={}&ReportType={}&FileFormat={}".format(job_id, report_type, file_format_id)
+        job_artifact_url = self.api_endpoint + "/get_report?job_id={}&report_type={}&file_format={}".format(job_id,
+                                                                                                           report_type,
+                                                                                                           file_format_id)
         try:
             job_status_response = requests.request("GET", job_artifact_url, params={}, headers=self.headers)
         except requests.RequestException as error:
