@@ -23,7 +23,6 @@ class ICVulnerabilityConfig:
         self.input_dimensions = None
         self.number_of_classes = None
         self.normalize_data = "yes"
-        self.number_of_attack_queries = 200
         self.model_framework = "tensorflow"
         self.encryption_strategy = 0
         self.defense_bestonly = "no"
@@ -76,16 +75,10 @@ class ICVulnerabilityConfig:
 
     @normalize_data.setter
     def normalize_data(self, normalize_data):
+        if normalize_data.lower() not in ['yes', 'no']:
+            raise Exception('normalize_data field can be yes or no')
         self.__normalize_data = normalize_data
 
-    @property
-    def number_of_attack_queries(self):
-        return self.__number_of_attack_queries
-
-    @number_of_attack_queries.setter
-    def number_of_attack_queries(self, num_attack_queries):
-        self.__number_of_attack_queries = num_attack_queries
-
     @property
     def model_framework(self):
         return self.__model_framework
@@ -115,43 +108,3 @@ class ICVulnerabilityConfig:
     @defense_bestonly.setter
     def defense_bestonly(self, defense_bestonly):
         self.__defense_bestonly = defense_bestonly
-
-
-class ICVulnerabilityAnalysis:
-    """
-    Instantiate for performing vulnerability analysis
-    """
-    def __init__(self, model_id: str, payload: dict):
-        self.model_id = model_id
-        self.payload = payload
-
-    @property
-    def model_id(self):
-        return self.__model_id
-
-    @model_id.setter
-    def model_id(self, model_id):
-        if not model_id:
-            raise Exception('model_id must be provided for vulnerability analysis')
-        self.__model_id = model_id
-
-    @property
-    def payload(self):
-        return self.__payload
-
-    @payload.setter
-    def payload(self, payload):
-        if not payload:
-            raise Exception('vuln_config details must be provided for vulnerability analysis')
-        self.__payload = payload
-
-    def prep_analysis_payload(self):
-        """
-        Prepares the payload required to perform the vulnerability analysis
-
-        Returns
-        -------
-        payload: configs of vulnerability analysis
-        """
-        self.payload['model_id'] = self.model_id
-        return self.payload
