@@ -1,16 +1,23 @@
 from aishield.constants import Attack
-from aishield.image_classification.base_ic import (
-    ICVulnerabilityConfig,
-    ICVulnerabilityAnalysis
-)
+from aishield.image_classification.base_ic import ICVulnerabilityConfig
+from aishield.utils.util import delete_keys_from_dict
 
 
 class VulnConfig(ICVulnerabilityConfig):
     def __init__(self, defense_generate):
         super().__init__(defense_generate)
+        self.number_of_attack_queries = 200
         self.attack_type = 'blackbox'
         self.attack = Attack.EXTRACTION
 
+    @property
+    def number_of_attack_queries(self):
+        return self.__number_of_attack_queries
+
+    @number_of_attack_queries.setter
+    def number_of_attack_queries(self, num_attack_queries):
+        self.__number_of_attack_queries = num_attack_queries
+
     @property
     def attack_type(self):
         return self.__attack_type
@@ -21,9 +28,5 @@ class VulnConfig(ICVulnerabilityConfig):
 
     def get_all_params(self):
         params = super(VulnConfig, self).get_all_params()
+        params = delete_keys_from_dict(params, ['task_type', 'attack'])
         return params
-
-
-
-class VulnAnalysis(ICVulnerabilityAnalysis):
-    pass
